@@ -1,9 +1,12 @@
-from moviepy.decorators import requires_duration
+
 import threading
 import time
 import pygame as pg
 import numpy as np
 
+from moviepy.decorators import requires_duration
+from moviepy.tools import cvsecs
+
 
 pg.init()
 pg.display.set_caption('MoviePy')
@@ -33,6 +36,9 @@ def show(clip, t=0, with_mask=True):
     
     """
 
+    if isinstance(t, tuple):
+        t = cvsecs(*t)
+
     if clip.ismask:
         clip = clip.to_RGB()
     if with_mask and (clip.mask != None):
